@@ -126,83 +126,87 @@ extern int c_debug;
     VAR_DROP_UPDATES = 327,        /* VAR_DROP_UPDATES  */
     VAR_XFRD_TCP_MAX = 328,        /* VAR_XFRD_TCP_MAX  */
     VAR_XFRD_TCP_PIPELINE = 329,   /* VAR_XFRD_TCP_PIPELINE  */
-    VAR_DNSTAP = 330,              /* VAR_DNSTAP  */
-    VAR_DNSTAP_ENABLE = 331,       /* VAR_DNSTAP_ENABLE  */
-    VAR_DNSTAP_SOCKET_PATH = 332,  /* VAR_DNSTAP_SOCKET_PATH  */
-    VAR_DNSTAP_IP = 333,           /* VAR_DNSTAP_IP  */
-    VAR_DNSTAP_TLS = 334,          /* VAR_DNSTAP_TLS  */
-    VAR_DNSTAP_TLS_SERVER_NAME = 335, /* VAR_DNSTAP_TLS_SERVER_NAME  */
-    VAR_DNSTAP_TLS_CERT_BUNDLE = 336, /* VAR_DNSTAP_TLS_CERT_BUNDLE  */
-    VAR_DNSTAP_TLS_CLIENT_KEY_FILE = 337, /* VAR_DNSTAP_TLS_CLIENT_KEY_FILE  */
-    VAR_DNSTAP_TLS_CLIENT_CERT_FILE = 338, /* VAR_DNSTAP_TLS_CLIENT_CERT_FILE  */
-    VAR_DNSTAP_SEND_IDENTITY = 339, /* VAR_DNSTAP_SEND_IDENTITY  */
-    VAR_DNSTAP_SEND_VERSION = 340, /* VAR_DNSTAP_SEND_VERSION  */
-    VAR_DNSTAP_IDENTITY = 341,     /* VAR_DNSTAP_IDENTITY  */
-    VAR_DNSTAP_VERSION = 342,      /* VAR_DNSTAP_VERSION  */
-    VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES = 343, /* VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES  */
-    VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES = 344, /* VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES  */
-    VAR_REMOTE_CONTROL = 345,      /* VAR_REMOTE_CONTROL  */
-    VAR_CONTROL_ENABLE = 346,      /* VAR_CONTROL_ENABLE  */
-    VAR_CONTROL_INTERFACE = 347,   /* VAR_CONTROL_INTERFACE  */
-    VAR_CONTROL_PORT = 348,        /* VAR_CONTROL_PORT  */
-    VAR_SERVER_KEY_FILE = 349,     /* VAR_SERVER_KEY_FILE  */
-    VAR_SERVER_CERT_FILE = 350,    /* VAR_SERVER_CERT_FILE  */
-    VAR_CONTROL_KEY_FILE = 351,    /* VAR_CONTROL_KEY_FILE  */
-    VAR_CONTROL_CERT_FILE = 352,   /* VAR_CONTROL_CERT_FILE  */
-    VAR_KEY = 353,                 /* VAR_KEY  */
-    VAR_ALGORITHM = 354,           /* VAR_ALGORITHM  */
-    VAR_SECRET = 355,              /* VAR_SECRET  */
-    VAR_TLS_AUTH = 356,            /* VAR_TLS_AUTH  */
-    VAR_TLS_AUTH_DOMAIN_NAME = 357, /* VAR_TLS_AUTH_DOMAIN_NAME  */
-    VAR_TLS_AUTH_CLIENT_CERT = 358, /* VAR_TLS_AUTH_CLIENT_CERT  */
-    VAR_TLS_AUTH_CLIENT_KEY = 359, /* VAR_TLS_AUTH_CLIENT_KEY  */
-    VAR_TLS_AUTH_CLIENT_KEY_PW = 360, /* VAR_TLS_AUTH_CLIENT_KEY_PW  */
-    VAR_PATTERN = 361,             /* VAR_PATTERN  */
-    VAR_NAME = 362,                /* VAR_NAME  */
-    VAR_ZONEFILE = 363,            /* VAR_ZONEFILE  */
-    VAR_NOTIFY = 364,              /* VAR_NOTIFY  */
-    VAR_PROVIDE_XFR = 365,         /* VAR_PROVIDE_XFR  */
-    VAR_ALLOW_QUERY = 366,         /* VAR_ALLOW_QUERY  */
-    VAR_AXFR = 367,                /* VAR_AXFR  */
-    VAR_UDP = 368,                 /* VAR_UDP  */
-    VAR_NOTIFY_RETRY = 369,        /* VAR_NOTIFY_RETRY  */
-    VAR_ALLOW_NOTIFY = 370,        /* VAR_ALLOW_NOTIFY  */
-    VAR_REQUEST_XFR = 371,         /* VAR_REQUEST_XFR  */
-    VAR_ALLOW_AXFR_FALLBACK = 372, /* VAR_ALLOW_AXFR_FALLBACK  */
-    VAR_OUTGOING_INTERFACE = 373,  /* VAR_OUTGOING_INTERFACE  */
-    VAR_ANSWER_COOKIE = 374,       /* VAR_ANSWER_COOKIE  */
-    VAR_COOKIE_SECRET = 375,       /* VAR_COOKIE_SECRET  */
-    VAR_COOKIE_SECRET_FILE = 376,  /* VAR_COOKIE_SECRET_FILE  */
-    VAR_COOKIE_STAGING_SECRET = 377, /* VAR_COOKIE_STAGING_SECRET  */
-    VAR_MAX_REFRESH_TIME = 378,    /* VAR_MAX_REFRESH_TIME  */
-    VAR_MIN_REFRESH_TIME = 379,    /* VAR_MIN_REFRESH_TIME  */
-    VAR_MAX_RETRY_TIME = 380,      /* VAR_MAX_RETRY_TIME  */
-    VAR_MIN_RETRY_TIME = 381,      /* VAR_MIN_RETRY_TIME  */
-    VAR_MIN_EXPIRE_TIME = 382,     /* VAR_MIN_EXPIRE_TIME  */
-    VAR_MULTI_PRIMARY_CHECK = 383, /* VAR_MULTI_PRIMARY_CHECK  */
-    VAR_SIZE_LIMIT_XFR = 384,      /* VAR_SIZE_LIMIT_XFR  */
-    VAR_ZONESTATS = 385,           /* VAR_ZONESTATS  */
-    VAR_INCLUDE_PATTERN = 386,     /* VAR_INCLUDE_PATTERN  */
-    VAR_STORE_IXFR = 387,          /* VAR_STORE_IXFR  */
-    VAR_IXFR_SIZE = 388,           /* VAR_IXFR_SIZE  */
-    VAR_IXFR_NUMBER = 389,         /* VAR_IXFR_NUMBER  */
-    VAR_CREATE_IXFR = 390,         /* VAR_CREATE_IXFR  */
-    VAR_CATALOG = 391,             /* VAR_CATALOG  */
-    VAR_CATALOG_MEMBER_PATTERN = 392, /* VAR_CATALOG_MEMBER_PATTERN  */
-    VAR_CATALOG_PRODUCER_ZONE = 393, /* VAR_CATALOG_PRODUCER_ZONE  */
-    VAR_ZONE = 394,                /* VAR_ZONE  */
-    VAR_RRL_WHITELIST = 395,       /* VAR_RRL_WHITELIST  */
-    VAR_SERVERS = 396,             /* VAR_SERVERS  */
-    VAR_BINDTODEVICE = 397,        /* VAR_BINDTODEVICE  */
-    VAR_SETFIB = 398,              /* VAR_SETFIB  */
-    VAR_VERIFY = 399,              /* VAR_VERIFY  */
-    VAR_ENABLE = 400,              /* VAR_ENABLE  */
-    VAR_VERIFY_ZONE = 401,         /* VAR_VERIFY_ZONE  */
-    VAR_VERIFY_ZONES = 402,        /* VAR_VERIFY_ZONES  */
-    VAR_VERIFIER = 403,            /* VAR_VERIFIER  */
-    VAR_VERIFIER_COUNT = 404,      /* VAR_VERIFIER_COUNT  */
-    VAR_VERIFIER_FEED_ZONE = 405,  /* VAR_VERIFIER_FEED_ZONE  */
-    VAR_VERIFIER_TIMEOUT = 406     /* VAR_VERIFIER_TIMEOUT  */
+    VAR_METRICS_ENABLE = 330,      /* VAR_METRICS_ENABLE  */
+    VAR_METRICS_INTERFACE = 331,   /* VAR_METRICS_INTERFACE  */
+    VAR_METRICS_PORT = 332,        /* VAR_METRICS_PORT  */
+    VAR_METRICS_PATH = 333,        /* VAR_METRICS_PATH  */
+    VAR_DNSTAP = 334,              /* VAR_DNSTAP  */
+    VAR_DNSTAP_ENABLE = 335,       /* VAR_DNSTAP_ENABLE  */
+    VAR_DNSTAP_SOCKET_PATH = 336,  /* VAR_DNSTAP_SOCKET_PATH  */
+    VAR_DNSTAP_IP = 337,           /* VAR_DNSTAP_IP  */
+    VAR_DNSTAP_TLS = 338,          /* VAR_DNSTAP_TLS  */
+    VAR_DNSTAP_TLS_SERVER_NAME = 339, /* VAR_DNSTAP_TLS_SERVER_NAME  */
+    VAR_DNSTAP_TLS_CERT_BUNDLE = 340, /* VAR_DNSTAP_TLS_CERT_BUNDLE  */
+    VAR_DNSTAP_TLS_CLIENT_KEY_FILE = 341, /* VAR_DNSTAP_TLS_CLIENT_KEY_FILE  */
+    VAR_DNSTAP_TLS_CLIENT_CERT_FILE = 342, /* VAR_DNSTAP_TLS_CLIENT_CERT_FILE  */
+    VAR_DNSTAP_SEND_IDENTITY = 343, /* VAR_DNSTAP_SEND_IDENTITY  */
+    VAR_DNSTAP_SEND_VERSION = 344, /* VAR_DNSTAP_SEND_VERSION  */
+    VAR_DNSTAP_IDENTITY = 345,     /* VAR_DNSTAP_IDENTITY  */
+    VAR_DNSTAP_VERSION = 346,      /* VAR_DNSTAP_VERSION  */
+    VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES = 347, /* VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES  */
+    VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES = 348, /* VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES  */
+    VAR_REMOTE_CONTROL = 349,      /* VAR_REMOTE_CONTROL  */
+    VAR_CONTROL_ENABLE = 350,      /* VAR_CONTROL_ENABLE  */
+    VAR_CONTROL_INTERFACE = 351,   /* VAR_CONTROL_INTERFACE  */
+    VAR_CONTROL_PORT = 352,        /* VAR_CONTROL_PORT  */
+    VAR_SERVER_KEY_FILE = 353,     /* VAR_SERVER_KEY_FILE  */
+    VAR_SERVER_CERT_FILE = 354,    /* VAR_SERVER_CERT_FILE  */
+    VAR_CONTROL_KEY_FILE = 355,    /* VAR_CONTROL_KEY_FILE  */
+    VAR_CONTROL_CERT_FILE = 356,   /* VAR_CONTROL_CERT_FILE  */
+    VAR_KEY = 357,                 /* VAR_KEY  */
+    VAR_ALGORITHM = 358,           /* VAR_ALGORITHM  */
+    VAR_SECRET = 359,              /* VAR_SECRET  */
+    VAR_TLS_AUTH = 360,            /* VAR_TLS_AUTH  */
+    VAR_TLS_AUTH_DOMAIN_NAME = 361, /* VAR_TLS_AUTH_DOMAIN_NAME  */
+    VAR_TLS_AUTH_CLIENT_CERT = 362, /* VAR_TLS_AUTH_CLIENT_CERT  */
+    VAR_TLS_AUTH_CLIENT_KEY = 363, /* VAR_TLS_AUTH_CLIENT_KEY  */
+    VAR_TLS_AUTH_CLIENT_KEY_PW = 364, /* VAR_TLS_AUTH_CLIENT_KEY_PW  */
+    VAR_PATTERN = 365,             /* VAR_PATTERN  */
+    VAR_NAME = 366,                /* VAR_NAME  */
+    VAR_ZONEFILE = 367,            /* VAR_ZONEFILE  */
+    VAR_NOTIFY = 368,              /* VAR_NOTIFY  */
+    VAR_PROVIDE_XFR = 369,         /* VAR_PROVIDE_XFR  */
+    VAR_ALLOW_QUERY = 370,         /* VAR_ALLOW_QUERY  */
+    VAR_AXFR = 371,                /* VAR_AXFR  */
+    VAR_UDP = 372,                 /* VAR_UDP  */
+    VAR_NOTIFY_RETRY = 373,        /* VAR_NOTIFY_RETRY  */
+    VAR_ALLOW_NOTIFY = 374,        /* VAR_ALLOW_NOTIFY  */
+    VAR_REQUEST_XFR = 375,         /* VAR_REQUEST_XFR  */
+    VAR_ALLOW_AXFR_FALLBACK = 376, /* VAR_ALLOW_AXFR_FALLBACK  */
+    VAR_OUTGOING_INTERFACE = 377,  /* VAR_OUTGOING_INTERFACE  */
+    VAR_ANSWER_COOKIE = 378,       /* VAR_ANSWER_COOKIE  */
+    VAR_COOKIE_SECRET = 379,       /* VAR_COOKIE_SECRET  */
+    VAR_COOKIE_SECRET_FILE = 380,  /* VAR_COOKIE_SECRET_FILE  */
+    VAR_COOKIE_STAGING_SECRET = 381, /* VAR_COOKIE_STAGING_SECRET  */
+    VAR_MAX_REFRESH_TIME = 382,    /* VAR_MAX_REFRESH_TIME  */
+    VAR_MIN_REFRESH_TIME = 383,    /* VAR_MIN_REFRESH_TIME  */
+    VAR_MAX_RETRY_TIME = 384,      /* VAR_MAX_RETRY_TIME  */
+    VAR_MIN_RETRY_TIME = 385,      /* VAR_MIN_RETRY_TIME  */
+    VAR_MIN_EXPIRE_TIME = 386,     /* VAR_MIN_EXPIRE_TIME  */
+    VAR_MULTI_PRIMARY_CHECK = 387, /* VAR_MULTI_PRIMARY_CHECK  */
+    VAR_SIZE_LIMIT_XFR = 388,      /* VAR_SIZE_LIMIT_XFR  */
+    VAR_ZONESTATS = 389,           /* VAR_ZONESTATS  */
+    VAR_INCLUDE_PATTERN = 390,     /* VAR_INCLUDE_PATTERN  */
+    VAR_STORE_IXFR = 391,          /* VAR_STORE_IXFR  */
+    VAR_IXFR_SIZE = 392,           /* VAR_IXFR_SIZE  */
+    VAR_IXFR_NUMBER = 393,         /* VAR_IXFR_NUMBER  */
+    VAR_CREATE_IXFR = 394,         /* VAR_CREATE_IXFR  */
+    VAR_CATALOG = 395,             /* VAR_CATALOG  */
+    VAR_CATALOG_MEMBER_PATTERN = 396, /* VAR_CATALOG_MEMBER_PATTERN  */
+    VAR_CATALOG_PRODUCER_ZONE = 397, /* VAR_CATALOG_PRODUCER_ZONE  */
+    VAR_ZONE = 398,                /* VAR_ZONE  */
+    VAR_RRL_WHITELIST = 399,       /* VAR_RRL_WHITELIST  */
+    VAR_SERVERS = 400,             /* VAR_SERVERS  */
+    VAR_BINDTODEVICE = 401,        /* VAR_BINDTODEVICE  */
+    VAR_SETFIB = 402,              /* VAR_SETFIB  */
+    VAR_VERIFY = 403,              /* VAR_VERIFY  */
+    VAR_ENABLE = 404,              /* VAR_ENABLE  */
+    VAR_VERIFY_ZONE = 405,         /* VAR_VERIFY_ZONE  */
+    VAR_VERIFY_ZONES = 406,        /* VAR_VERIFY_ZONES  */
+    VAR_VERIFIER = 407,            /* VAR_VERIFIER  */
+    VAR_VERIFIER_COUNT = 408,      /* VAR_VERIFIER_COUNT  */
+    VAR_VERIFIER_FEED_ZONE = 409,  /* VAR_VERIFIER_FEED_ZONE  */
+    VAR_VERIFIER_TIMEOUT = 410     /* VAR_VERIFIER_TIMEOUT  */
   };
   typedef enum yytokentype yytoken_kind_t;
 #endif
@@ -283,83 +287,87 @@ extern int c_debug;
 #define VAR_DROP_UPDATES 327
 #define VAR_XFRD_TCP_MAX 328
 #define VAR_XFRD_TCP_PIPELINE 329
-#define VAR_DNSTAP 330
-#define VAR_DNSTAP_ENABLE 331
-#define VAR_DNSTAP_SOCKET_PATH 332
-#define VAR_DNSTAP_IP 333
-#define VAR_DNSTAP_TLS 334
-#define VAR_DNSTAP_TLS_SERVER_NAME 335
-#define VAR_DNSTAP_TLS_CERT_BUNDLE 336
-#define VAR_DNSTAP_TLS_CLIENT_KEY_FILE 337
-#define VAR_DNSTAP_TLS_CLIENT_CERT_FILE 338
-#define VAR_DNSTAP_SEND_IDENTITY 339
-#define VAR_DNSTAP_SEND_VERSION 340
-#define VAR_DNSTAP_IDENTITY 341
-#define VAR_DNSTAP_VERSION 342
-#define VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES 343
-#define VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES 344
-#define VAR_REMOTE_CONTROL 345
-#define VAR_CONTROL_ENABLE 346
-#define VAR_CONTROL_INTERFACE 347
-#define VAR_CONTROL_PORT 348
-#define VAR_SERVER_KEY_FILE 349
-#define VAR_SERVER_CERT_FILE 350
-#define VAR_CONTROL_KEY_FILE 351
-#define VAR_CONTROL_CERT_FILE 352
-#define VAR_KEY 353
-#define VAR_ALGORITHM 354
-#define VAR_SECRET 355
-#define VAR_TLS_AUTH 356
-#define VAR_TLS_AUTH_DOMAIN_NAME 357
-#define VAR_TLS_AUTH_CLIENT_CERT 358
-#define VAR_TLS_AUTH_CLIENT_KEY 359
-#define VAR_TLS_AUTH_CLIENT_KEY_PW 360
-#define VAR_PATTERN 361
-#define VAR_NAME 362
-#define VAR_ZONEFILE 363
-#define VAR_NOTIFY 364
-#define VAR_PROVIDE_XFR 365
-#define VAR_ALLOW_QUERY 366
-#define VAR_AXFR 367
-#define VAR_UDP 368
-#define VAR_NOTIFY_RETRY 369
-#define VAR_ALLOW_NOTIFY 370
-#define VAR_REQUEST_XFR 371
-#define VAR_ALLOW_AXFR_FALLBACK 372
-#define VAR_OUTGOING_INTERFACE 373
-#define VAR_ANSWER_COOKIE 374
-#define VAR_COOKIE_SECRET 375
-#define VAR_COOKIE_SECRET_FILE 376
-#define VAR_COOKIE_STAGING_SECRET 377
-#define VAR_MAX_REFRESH_TIME 378
-#define VAR_MIN_REFRESH_TIME 379
-#define VAR_MAX_RETRY_TIME 380
-#define VAR_MIN_RETRY_TIME 381
-#define VAR_MIN_EXPIRE_TIME 382
-#define VAR_MULTI_PRIMARY_CHECK 383
-#define VAR_SIZE_LIMIT_XFR 384
-#define VAR_ZONESTATS 385
-#define VAR_INCLUDE_PATTERN 386
-#define VAR_STORE_IXFR 387
-#define VAR_IXFR_SIZE 388
-#define VAR_IXFR_NUMBER 389
-#define VAR_CREATE_IXFR 390
-#define VAR_CATALOG 391
-#define VAR_CATALOG_MEMBER_PATTERN 392
-#define VAR_CATALOG_PRODUCER_ZONE 393
-#define VAR_ZONE 394
-#define VAR_RRL_WHITELIST 395
-#define VAR_SERVERS 396
-#define VAR_BINDTODEVICE 397
-#define VAR_SETFIB 398
-#define VAR_VERIFY 399
-#define VAR_ENABLE 400
-#define VAR_VERIFY_ZONE 401
-#define VAR_VERIFY_ZONES 402
-#define VAR_VERIFIER 403
-#define VAR_VERIFIER_COUNT 404
-#define VAR_VERIFIER_FEED_ZONE 405
-#define VAR_VERIFIER_TIMEOUT 406
+#define VAR_METRICS_ENABLE 330
+#define VAR_METRICS_INTERFACE 331
+#define VAR_METRICS_PORT 332
+#define VAR_METRICS_PATH 333
+#define VAR_DNSTAP 334
+#define VAR_DNSTAP_ENABLE 335
+#define VAR_DNSTAP_SOCKET_PATH 336
+#define VAR_DNSTAP_IP 337
+#define VAR_DNSTAP_TLS 338
+#define VAR_DNSTAP_TLS_SERVER_NAME 339
+#define VAR_DNSTAP_TLS_CERT_BUNDLE 340
+#define VAR_DNSTAP_TLS_CLIENT_KEY_FILE 341
+#define VAR_DNSTAP_TLS_CLIENT_CERT_FILE 342
+#define VAR_DNSTAP_SEND_IDENTITY 343
+#define VAR_DNSTAP_SEND_VERSION 344
+#define VAR_DNSTAP_IDENTITY 345
+#define VAR_DNSTAP_VERSION 346
+#define VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES 347
+#define VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES 348
+#define VAR_REMOTE_CONTROL 349
+#define VAR_CONTROL_ENABLE 350
+#define VAR_CONTROL_INTERFACE 351
+#define VAR_CONTROL_PORT 352
+#define VAR_SERVER_KEY_FILE 353
+#define VAR_SERVER_CERT_FILE 354
+#define VAR_CONTROL_KEY_FILE 355
+#define VAR_CONTROL_CERT_FILE 356
+#define VAR_KEY 357
+#define VAR_ALGORITHM 358
+#define VAR_SECRET 359
+#define VAR_TLS_AUTH 360
+#define VAR_TLS_AUTH_DOMAIN_NAME 361
+#define VAR_TLS_AUTH_CLIENT_CERT 362
+#define VAR_TLS_AUTH_CLIENT_KEY 363
+#define VAR_TLS_AUTH_CLIENT_KEY_PW 364
+#define VAR_PATTERN 365
+#define VAR_NAME 366
+#define VAR_ZONEFILE 367
+#define VAR_NOTIFY 368
+#define VAR_PROVIDE_XFR 369
+#define VAR_ALLOW_QUERY 370
+#define VAR_AXFR 371
+#define VAR_UDP 372
+#define VAR_NOTIFY_RETRY 373
+#define VAR_ALLOW_NOTIFY 374
+#define VAR_REQUEST_XFR 375
+#define VAR_ALLOW_AXFR_FALLBACK 376
+#define VAR_OUTGOING_INTERFACE 377
+#define VAR_ANSWER_COOKIE 378
+#define VAR_COOKIE_SECRET 379
+#define VAR_COOKIE_SECRET_FILE 380
+#define VAR_COOKIE_STAGING_SECRET 381
+#define VAR_MAX_REFRESH_TIME 382
+#define VAR_MIN_REFRESH_TIME 383
+#define VAR_MAX_RETRY_TIME 384
+#define VAR_MIN_RETRY_TIME 385
+#define VAR_MIN_EXPIRE_TIME 386
+#define VAR_MULTI_PRIMARY_CHECK 387
+#define VAR_SIZE_LIMIT_XFR 388
+#define VAR_ZONESTATS 389
+#define VAR_INCLUDE_PATTERN 390
+#define VAR_STORE_IXFR 391
+#define VAR_IXFR_SIZE 392
+#define VAR_IXFR_NUMBER 393
+#define VAR_CREATE_IXFR 394
+#define VAR_CATALOG 395
+#define VAR_CATALOG_MEMBER_PATTERN 396
+#define VAR_CATALOG_PRODUCER_ZONE 397
+#define VAR_ZONE 398
+#define VAR_RRL_WHITELIST 399
+#define VAR_SERVERS 400
+#define VAR_BINDTODEVICE 401
+#define VAR_SETFIB 402
+#define VAR_VERIFY 403
+#define VAR_ENABLE 404
+#define VAR_VERIFY_ZONE 405
+#define VAR_VERIFY_ZONES 406
+#define VAR_VERIFIER 407
+#define VAR_VERIFIER_COUNT 408
+#define VAR_VERIFIER_FEED_ZONE 409
+#define VAR_VERIFIER_TIMEOUT 410
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -377,7 +385,7 @@ union YYSTYPE
   struct component *comp;
   int role;
 
-#line 381 "configparser.h"
+#line 389 "configparser.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
