@@ -116,7 +116,7 @@ static rrtype_descriptor_type rrtype_descriptors[(RRTYPE_DESCRIPTORS_LENGTH+2)]
 	  { RDATA_ZF_NSAP } },
 	/* 23 */
 	{ TYPE_NSAP_PTR, "NSAP-PTR", 1, 1,
-	  { RDATA_WF_UNCOMPRESSED_DNAME }, { RDATA_ZF_DNAME } },
+	  { RDATA_WF_TEXT }, { RDATA_ZF_UNQUOTED } },
 	/* 24 */
 	{ TYPE_SIG, "SIG", 9, 9,
 	  { RDATA_WF_SHORT, RDATA_WF_BYTE, RDATA_WF_BYTE, RDATA_WF_LONG,
@@ -152,16 +152,16 @@ static rrtype_descriptor_type rrtype_descriptors[(RRTYPE_DESCRIPTORS_LENGTH+2)]
 	  { RDATA_WF_UNCOMPRESSED_DNAME, RDATA_WF_BINARY },
 	  { RDATA_ZF_DNAME, RDATA_ZF_NXT } },
 	/* 31 */
-	{ 31, NULL, 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
+	{ TYPE_EID, "EID", 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_HEX } },
 	/* 32 */
-	{ 32, NULL, 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
+	{ TYPE_NIMLOC, "NIMLOC", 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_HEX } },
 	/* 33 */
 	{ TYPE_SRV, "SRV", 4, 4,
 	  { RDATA_WF_SHORT, RDATA_WF_SHORT, RDATA_WF_SHORT,
 	    RDATA_WF_UNCOMPRESSED_DNAME },
 	  { RDATA_ZF_SHORT, RDATA_ZF_SHORT, RDATA_ZF_SHORT, RDATA_ZF_DNAME } },
 	/* 34 */
-	{ 34, NULL, 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
+	{ TYPE_ATMA, "ATMA", 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_ATMA } },
 	/* 35 */
 	{ TYPE_NAPTR, "NAPTR", 6, 6,
 	  { RDATA_WF_SHORT, RDATA_WF_SHORT, RDATA_WF_TEXT, RDATA_WF_TEXT,
@@ -183,7 +183,9 @@ static rrtype_descriptor_type rrtype_descriptors[(RRTYPE_DESCRIPTORS_LENGTH+2)]
 	{ TYPE_DNAME, "DNAME", 1, 1,
 	  { RDATA_WF_UNCOMPRESSED_DNAME }, { RDATA_ZF_DNAME } },
 	/* 40 */
-	{ 40, NULL, 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
+	{ TYPE_SINK, "SINK", 3, 3,
+	  { RDATA_WF_BYTE, RDATA_WF_BYTE, RDATA_WF_BINARY },
+	  { RDATA_ZF_BYTE, RDATA_ZF_BYTE, RDATA_ZF_BASE64 } },
 	/* 41 */
 	{ TYPE_OPT, "OPT", 1, 1,
 	  { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
@@ -363,7 +365,9 @@ static rrtype_descriptor_type rrtype_descriptors[(RRTYPE_DESCRIPTORS_LENGTH+2)]
 	  { RDATA_ZF_SHORT, RDATA_ZF_BYTE, RDATA_ZF_ALGORITHM,
 	    RDATA_ZF_BASE64 } },
 	/* 58 - TALINK */
-	{ 58, NULL, 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
+	{ TYPE_TALINK, "TALINK", 2, 2,
+	  { RDATA_WF_LITERAL_DNAME, RDATA_WF_LITERAL_DNAME },
+	  { RDATA_ZF_LITERAL_DNAME, RDATA_ZF_LITERAL_DNAME } },
 	/* 59 - CDS */
 	{ TYPE_CDS, "CDS", 4, 4,
 	  { RDATA_WF_SHORT, RDATA_WF_BYTE, RDATA_WF_BYTE, RDATA_WF_BINARY },
@@ -485,7 +489,11 @@ static rrtype_descriptor_type rrtype_descriptors[(RRTYPE_DESCRIPTORS_LENGTH+2)]
 	  , RDATA_ZF_SVCPARAM, RDATA_ZF_SVCPARAM, RDATA_ZF_SVCPARAM
 	  } },
 	/* 66 */
-	{ 66, NULL, 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
+	{ TYPE_DSYNC, "DSYNC", 4, 4,
+	  { RDATA_WF_SHORT , RDATA_WF_BYTE, RDATA_WF_SHORT
+	  , RDATA_WF_LITERAL_DNAME },
+	  { RDATA_ZF_RRTYPE, RDATA_ZF_BYTE, RDATA_ZF_SHORT
+	  , RDATA_ZF_LITERAL_DNAME } },
 	/* 67 */
 	{ 67, NULL, 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
 	/* 68 */
@@ -888,15 +896,23 @@ static rrtype_descriptor_type rrtype_descriptors[(RRTYPE_DESCRIPTORS_LENGTH+2)]
 	  { RDATA_WF_TEXTS },
 	  { RDATA_ZF_TEXTS } },
 	/* 259 - DOA */
-	{ 259, NULL, 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
+	{ TYPE_DOA, "DOA", 5, 5,
+	  { RDATA_WF_LONG, RDATA_WF_LONG, RDATA_WF_BYTE,
+	    RDATA_WF_TEXT, RDATA_WF_BINARY },
+	  { RDATA_ZF_LONG, RDATA_ZF_LONG, RDATA_ZF_BYTE,
+	    RDATA_ZF_TEXT, RDATA_ZF_BASE64 } },
 	/* 260 - AMTRELAY */
-	{ 260, NULL, 1, 1, { RDATA_WF_BINARY }, { RDATA_ZF_UNKNOWN } },
+	{ TYPE_AMTRELAY, "AMTRELAY", 3, 3,
+	  { RDATA_WF_BYTE, RDATA_WF_BYTE           , RDATA_WF_AMTRELAY_RELAY },
+	  { RDATA_ZF_BYTE, RDATA_ZF_AMTRELAY_D_TYPE, RDATA_ZF_AMTRELAY_RELAY } },
 	/* 261 - RESINFO */
 	{ TYPE_RESINFO, "RESINFO", 1, 1, { RDATA_WF_TEXTS }, { RDATA_ZF_UNQUOTEDS } },
 	/* 262 - WALLET */
 	{ TYPE_WALLET, "WALLET", 1, 1, { RDATA_WF_TEXTS }, { RDATA_ZF_TEXTS } },
 	/* 263 - CLA */
 	{ TYPE_CLA, "CLA", 1, 1, { RDATA_WF_TEXTS }, { RDATA_ZF_TEXTS } },
+	/* 264 - IPN */
+	{ TYPE_IPN, "IPN", 1, 1, { RDATA_WF_LONGLONG }, { RDATA_ZF_LONGLONG } },
 
 	/* 32768 - TA */
 	{ TYPE_TA, "TA", 4, 4,
