@@ -112,15 +112,16 @@ typedef enum nsd_rc nsd_rc_type;
 #define TYPE_AAAA	28	/* ipv6 address */
 #define TYPE_LOC	29	/* LOC record  RFC1876 */
 #define TYPE_NXT	30	/* 2535typecode */
-
+#define TYPE_EID	31	/* draft-ietf-nimrod-dns-01 */
+#define TYPE_NIMLOC	32	/* draft-ietf-nimrod-dns-01 */
 #define TYPE_SRV	33	/* SRV record RFC2782 */
-
+#define TYPE_ATMA	34	/* ATM Address */
 #define TYPE_NAPTR	35	/* RFC2915 */
 #define TYPE_KX		36	/* RFC2230 Key Exchange Delegation Record */
 #define TYPE_CERT	37	/* RFC2538 */
 #define TYPE_A6		38	/* RFC2874 */
 #define TYPE_DNAME	39	/* RFC2672 */
-
+#define TYPE_SINK	40	/* draft-eastlake-kitchen-sink */
 #define TYPE_OPT	41	/* Pseudo OPT record... */
 #define TYPE_APL	42	/* RFC3123 */
 #define TYPE_DS		43	/* RFC 4033, 4034, and 4035 */
@@ -137,7 +138,7 @@ typedef enum nsd_rc nsd_rc_type;
 #define TYPE_HIP	55	/* RFC 8005 */
 #define TYPE_NINFO	56	/* NINFO/ninfo-completed-template */
 #define TYPE_RKEY	57	/* RKEY/rkey-completed-template */
-
+#define TYPE_TALINK	58	/* draft-iet5f-dnsop-dnssec-trust-history */
 #define TYPE_CDS	59	/* RFC 7344 */
 #define TYPE_CDNSKEY	60	/* RFC 7344 */
 #define TYPE_OPENPGPKEY 61	/* RFC 7929 */
@@ -145,6 +146,7 @@ typedef enum nsd_rc nsd_rc_type;
 #define TYPE_ZONEMD	63	/* RFC 8976 */
 #define TYPE_SVCB	64	/* RFC 9460 */
 #define TYPE_HTTPS	65	/* RFC 9460 */
+#define TYPE_DSYNC	66	/* draft-ietf-dnsop-generalized-notify */
 
 #define TYPE_SPF        99      /* RFC 4408 */
 
@@ -164,10 +166,12 @@ typedef enum nsd_rc nsd_rc_type;
 #define TYPE_URI	256	/* RFC 7553 */
 #define TYPE_CAA	257	/* RFC 6844 */
 #define TYPE_AVC	258	/* AVC/avc-completed-template */
-
+#define TYPE_DOA	259	/* draft-durand-doa-over-dns */
+#define TYPE_AMTRELAY	260	/* RFC 8777 */
 #define TYPE_RESINFO	261	/* RFC 9606 */
 #define TYPE_WALLET	262	/* WALLET/wallet-completed-template */
 #define TYPE_CLA	263	/* CLA/cla-completed-template */
+#define TYPE_IPN	264	/* IPN/ipn-completed-template */
 
 #define TYPE_TA		32768	/* http://www.watson.org/~weiler/INI1999-19.pdf */
 #define TYPE_DLV	32769	/* RFC 4431 */
@@ -214,6 +218,7 @@ enum rdata_wireformat
 	RDATA_WF_BYTE,               /* 8-bit integer.  */
 	RDATA_WF_SHORT,              /* 16-bit integer.  */
 	RDATA_WF_LONG,               /* 32-bit integer.  */
+	RDATA_WF_LONGLONG,           /* 64-bit integer.  */
 	RDATA_WF_TEXT,               /* Text string.  */
 	RDATA_WF_TEXTS,              /* Text string sequence.  */
 	RDATA_WF_A,                  /* 32-bit IPv4 address.  */
@@ -227,7 +232,8 @@ enum rdata_wireformat
 	RDATA_WF_EUI64,              /* 64-bit address.  */
 	RDATA_WF_LONG_TEXT,          /* Long (>255) text string. */
 	RDATA_WF_SVCPARAM,           /* SvcParam <key>[=<value>] */
-	RDATA_WF_HIP                 /* HIP rdata up to the Rendezvous Servers */
+	RDATA_WF_HIP,                /* HIP rdata up to the Rendezvous Servers */
+	RDATA_WF_AMTRELAY_RELAY      /* ip4, ip6, dname or nothing */
 };
 typedef enum rdata_wireformat rdata_wireformat_type;
 
@@ -243,6 +249,7 @@ enum rdata_zoneformat
 	RDATA_ZF_BYTE,		/* 8-bit integer.  */
 	RDATA_ZF_SHORT,		/* 16-bit integer.  */
 	RDATA_ZF_LONG,		/* 32-bit integer.  */
+	RDATA_ZF_LONGLONG,	/* 64-bit integer.  */
 	RDATA_ZF_A,		/* 32-bit IPv4 address.  */
 	RDATA_ZF_AAAA,		/* 128-bit IPv6 address.  */
 	RDATA_ZF_RRTYPE,	/* RR type.  */
@@ -270,6 +277,9 @@ enum rdata_zoneformat
 	RDATA_ZF_TAG,		/* A sequence of letters and numbers. */
 	RDATA_ZF_SVCPARAM,	/* SvcParam <key>[=<value>] */
 	RDATA_ZF_HIP,		/* HIP rdata up to the Rendezvous Servers */
+	RDATA_ZF_ATMA,		/* ATM Address */
+	RDATA_ZF_AMTRELAY_D_TYPE,/* Discovery Optional and Type */
+	RDATA_ZF_AMTRELAY_RELAY,/* ip4, ip6, dname or nothing */
 	RDATA_ZF_UNKNOWN	/* Unknown data.  */
 };
 typedef enum rdata_zoneformat rdata_zoneformat_type;
@@ -291,7 +301,7 @@ typedef struct rrtype_descriptor rrtype_descriptor_type;
  *
  * CLA + 1
  */
-#define RRTYPE_DESCRIPTORS_LENGTH  (TYPE_CLA + 1)
+#define RRTYPE_DESCRIPTORS_LENGTH  (TYPE_IPN + 1)
 rrtype_descriptor_type *rrtype_descriptor_by_name(const char *name);
 rrtype_descriptor_type *rrtype_descriptor_by_type(uint16_t type);
 
