@@ -38,8 +38,8 @@
  * blocked in pselect(2).
  */
 
-#ifndef _NETIO_H_
-#define _NETIO_H_
+#ifndef NETIO_H
+#define NETIO_H
 
 #ifdef	HAVE_SYS_SELECT_H
 #include <sys/select.h>
@@ -174,17 +174,4 @@ int netio_dispatch(netio_type *netio,
 		   const struct timespec *timeout,
 		   const sigset_t *sigmask);
 
-
-#ifdef __cplusplus
-inline netio_event_types_type
-operator | (netio_event_types_type lhs, netio_event_types_type rhs) {
-	return (netio_event_types_type) (lhs | rhs);
-}
-inline netio_event_types_type
-operator |= (netio_event_types_type &lhs, netio_event_types_type rhs) {
-	lhs = (netio_event_types_type) (lhs | rhs);
-	return lhs;
-}
-#endif /* __cplusplus */
-
-#endif /* _NETIO_H_ */
+#endif /* NETIO_H */
