@@ -54,6 +54,9 @@
 #include "remote.h"
 #include "xfrd-disk.h"
 #include "ipc.h"
+#ifdef USE_METRICS
+#include "metrics.h"
+#endif /* USE_METRICS */
 #ifdef USE_DNSTAP
 #include "dnstap/dnstap_collector.h"
 #endif
@@ -544,7 +547,7 @@ print_socket_servers(struct nsd_socket *sock, char *buf, size_t bufsz)
 			cnt = 0;
 			if (i == n && x == -1) {
 				assert(y == -1);
-				assert(z == -1);
+				assert(z == (n - 1));
 				cnt = snprintf(buf, bufsz, "-");
 			} else if (y > z) {
 				assert(x > z);
@@ -1517,6 +1520,12 @@ main(int argc, char *argv[])
 		if(!(nsd.rc = daemon_remote_create(nsd.options)))
 			error("could not perform remote control setup");
 	}
+#ifdef USE_METRICS
+	if(nsd.options->metrics_enable) {
+		if(!(nsd.metrics = daemon_metrics_create(nsd.options)))
+			error("could not perform metrics server setup");
+	}
+#endif /* USE_METRICS */
 #if defined(HAVE_SSL)
 	if(nsd.options->tls_service_key && nsd.options->tls_service_key[0]
 	   && nsd.options->tls_service_pem && nsd.options->tls_service_pem[0]) {
