@@ -18,38 +18,38 @@ static const struct {
   const mnemonic_t *mnemonic;
   int32_t code;
 } types_and_classes[256] = {
-    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),  T(20),
-    T(3),   V(0),   V(0),   V(0),   V(0), T(261),   V(0),   V(0),
-   T(60),   V(0),   V(0), T(105),   V(0),   V(0),   V(0), T(258),
-    V(0),   V(0),   V(0),   V(0),  T(30),   V(0),  T(28),   V(0),
-    V(0),  T(16),   V(0),   V(0),  T(56),  T(14),  T(22),   V(0),
-    V(0),  T(13),   V(0),  T(47),  T(21),   V(0),  T(65),  T(27),
-    V(0),   V(0),   V(0),   V(0),   V(0),   T(1),  T(62),   V(0),
-    V(0),   C(1),   V(0),  T(44),   V(0),   V(0),  T(33),   V(0),
-    V(0),   V(0),   V(0),   V(0),  T(63),   V(0), T(266),   V(0),
-    C(3),  T(99),  T(37),   V(0),   V(0),   V(0),   C(2),  T(43),
-    V(0),  T(50),   C(4),  T(51),   V(0),   V(0),   V(0),   T(2),
-   T(49),  T(42),  T(19),  T(23),   V(0),   T(6),   V(0),   V(0),
-    V(0),   V(0),  T(29),   V(0),   T(7),   V(0),   V(0),   V(0),
-    V(0),  T(57),   V(0),   V(0),   V(0),   V(0),   V(0),  T(36),
-   T(15),   V(0),   V(0),  T(26),  T(11),   V(0),   V(0),   V(0),
-    V(0),   V(0),   V(0),   V(0), T(104),   V(0),   T(8),   V(0),
-    V(0),   V(0),  T(38),   V(0),   T(9),   V(0),  T(64),   V(0),
-    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),  T(39),  T(52),
-   T(24),   V(0),   T(5), T(106),   V(0),   V(0),   V(0),   V(0),
-  T(265),   V(0),   V(0),   V(0),   V(0),  T(25),   V(0),  T(18),
-   T(48),   V(0),  T(53),   V(0),   V(0),   V(0),  T(59),   V(0),
-    V(0),   V(0),   V(0),   V(0),   T(4),   V(0),  T(10),   V(0),
-    V(0),   V(0),   V(0),   V(0),   V(0),  T(55),   V(0),   V(0),
-    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),
-    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),
-    V(0),   V(0),  T(61),  T(12),   V(0),   V(0),   V(0),   V(0),
-    V(0), T(108),   V(0),   V(0), T(257),   V(0),   V(0),   V(0),
-   T(35),   V(0), T(263),   V(0),   V(0),   V(0),   V(0), T(107),
-    V(0),   V(0),   V(0),   V(0),  T(17),   V(0),  T(45),   V(0),
-    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),  T(46),   V(0),
-    V(0), T(109),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),
-    V(0),   V(0),   V(0),   V(0), T(262),   V(0), T(256),   V(0)
+    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),  T(34),   V(0),
+    V(0),   V(0),  T(30),   V(0),   V(0),  T(57),   V(0),  T(16),
+    V(0),   V(0),  T(56),  T(14),  T(12),   V(0),   V(0),  T(13),
+   T(61),   V(0), T(105),   V(0),   V(0),   V(0),  T(32), T(258),
+    V(0), T(107),  T(47),   V(0),   V(0),   V(0),  T(17),   V(0),
+  T(257),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),
+   T(65),   V(0),   V(0),  T(18),   V(0),   T(1),   V(0), T(263),
+    V(0),   V(0),   V(0),   V(0),  T(51),   V(0),   V(0), T(106),
+    T(3),   V(0),   V(0),  T(31),   V(0),   V(0),   V(0),   V(0),
+    V(0),  T(50),  T(44), T(104),  T(10),   V(0),   V(0),   V(0),
+    V(0),   V(0),  T(55),   V(0),  T(28),   V(0),   V(0),   V(0),
+    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),  T(39),
+   T(35),   V(0),   V(0),   T(5),  T(29), T(262),   V(0),   V(0),
+  T(109),   V(0), T(264),   V(0),   V(0),   V(0),   V(0),   V(0),
+    V(0),  T(21),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),
+   T(37),   C(1),  T(58),   V(0),   V(0),   V(0),   V(0),   V(0),
+    V(0),   V(0),   V(0),   C(3),   V(0),  T(52),  T(11),  T(20),
+    V(0), T(261),   V(0),   V(0),   V(0),  T(48),   V(0),   V(0),
+    V(0),  T(25),   C(2),  T(43),   V(0),   V(0),   C(4),  T(60),
+    V(0),   V(0),   T(7),   T(2),   V(0),   V(0),  T(46),  T(22),
+    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),  T(64),
+    V(0), T(260),   V(0),   V(0),   V(0),   V(0),  T(38),   V(0),
+    V(0), T(259),  T(59),   V(0),   V(0),   V(0),  T(42),  T(36),
+    T(8),  T(15),   V(0),  T(26),  T(27),   T(6),   V(0),  T(99),
+    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),  T(53),
+    T(9),  T(63),  T(33),   V(0), T(271), T(270),   V(0),  T(40),
+    V(0),   V(0),  T(24),  T(19),   V(0),   V(0),   V(0),   V(0),
+    V(0),   V(0),   V(0), T(108),   V(0),   V(0),   V(0),  T(62),
+    V(0),   V(0),   V(0),   V(0),   V(0),  T(66),   T(4),   V(0),
+    V(0),   V(0), T(256),   V(0),  T(49),   V(0),   V(0),   V(0),
+    V(0),   V(0),  T(45),   V(0),   V(0),  T(23),   V(0),   V(0),
+    V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0),   V(0)
 };
 
 #undef V
@@ -102,7 +102,7 @@ static really_inline uint8_t hash(uint64_t prefix)
 {
   uint32_t value = (uint32_t)((prefix >> 32) ^ prefix);
   // magic value is generated using hash.c, rerun when adding types
-  return (uint8_t)((value * 3523548378ull) >> 32);
+  return (uint8_t)((value * 3537259401ull) >> 32);
 }
 
 nonnull_all
