@@ -218,14 +218,6 @@ typedef enum udb_chunk_type udb_chunk_type;
 enum udb_chunk_type {
 	udb_chunk_type_free = 0,
 	udb_chunk_type_data, /* alloced data */
-	udb_chunk_type_index,
-	udb_chunk_type_radtree,
-	udb_chunk_type_radnode,
-	udb_chunk_type_radarray,
-	udb_chunk_type_zone,
-	udb_chunk_type_domain,
-	udb_chunk_type_rrset,
-	udb_chunk_type_rr,
 	udb_chunk_type_task,
 	udb_chunk_type_internal
 };
